pub struct FirecrawlApp { /* private fields */ }Implementations
Sourceimpl FirecrawlApp
impl FirecrawlApp
Sourcepub async fn batch_scrape_urls(
&self,
urls: Vec<String>,
options: impl Into<Option<ScrapeOptions>>,
poll_interval: Option<u64>,
idempotency_key: Option<String>,
webhook: Webhook,
ignore_invalid_urls: Option<bool>,
) -> Result<BatchScrapeStatus, FirecrawlError>
pub async fn batch_scrape_urls( &self, urls: Vec<String>, options: impl Into<Option<ScrapeOptions>>, poll_interval: Option<u64>, idempotency_key: Option<String>, webhook: Webhook, ignore_invalid_urls: Option<bool>, ) -> Result<BatchScrapeStatus, FirecrawlError>
Scrapes multiple URLs in a single request using the Firecrawl API.
Sourcepub async fn check_batch_scrape_status(
&self,
id: &str,
) -> Result<BatchScrapeStatus, FirecrawlError>
pub async fn check_batch_scrape_status( &self, id: &str, ) -> Result<BatchScrapeStatus, FirecrawlError>
Checks the status of a batch scrape job.
Sourcepub async fn monitor_batch_scrape_status(
&self,
id: &str,
poll_interval: u64,
) -> Result<BatchScrapeStatus, FirecrawlError>
pub async fn monitor_batch_scrape_status( &self, id: &str, poll_interval: u64, ) -> Result<BatchScrapeStatus, FirecrawlError>
Monitors a batch scrape job until it completes, fails, or is cancelled.
Sourcepub async fn check_batch_scrape_status_with_cursor(
&self,
id: &str,
cursor: &str,
) -> Result<BatchScrapeStatus, FirecrawlError>
pub async fn check_batch_scrape_status_with_cursor( &self, id: &str, cursor: &str, ) -> Result<BatchScrapeStatus, FirecrawlError>
Checks the status of a batch scrape job with a cursor for pagination.
Sourceimpl FirecrawlApp
impl FirecrawlApp
Sourcepub async fn crawl_url_async(
&self,
url: impl AsRef<str>,
options: Option<CrawlOptions>,
idempotency_key: Option<String>,
webhook: Webhook,
) -> Result<CrawlAsyncResponse, FirecrawlError>
pub async fn crawl_url_async( &self, url: impl AsRef<str>, options: Option<CrawlOptions>, idempotency_key: Option<String>, webhook: Webhook, ) -> Result<CrawlAsyncResponse, FirecrawlError>
Initiates a crawl job for a URL using the Firecrawl API.
Sourcepub async fn crawl_url(
&self,
url: impl AsRef<str>,
options: impl Into<Option<CrawlOptions>>,
webhook: Webhook,
poll_interval: Option<u64>,
idempotency_key: Option<String>,
) -> Result<CrawlStatus, FirecrawlError>
pub async fn crawl_url( &self, url: impl AsRef<str>, options: impl Into<Option<CrawlOptions>>, webhook: Webhook, poll_interval: Option<u64>, idempotency_key: Option<String>, ) -> Result<CrawlStatus, FirecrawlError>
Performs a crawl job for a URL using the Firecrawl API, waiting for the end result. This may take a long time depending on the size of the target page and your options (namely CrawlOptions.limit).
Sourcepub async fn check_crawl_status(
&self,
id: impl AsRef<str>,
) -> Result<CrawlStatus, FirecrawlError>
pub async fn check_crawl_status( &self, id: impl AsRef<str>, ) -> Result<CrawlStatus, FirecrawlError>
Checks for the status of a crawl, based on the crawl’s ID. To be used in conjunction with FirecrawlApp::crawl_url_async.
Sourceimpl FirecrawlApp
impl FirecrawlApp
Sourceimpl FirecrawlApp
impl FirecrawlApp
Sourcepub async fn scrape_url(
&self,
url: impl AsRef<str>,
options: impl Into<Option<ScrapeOptions>>,
) -> Result<Document, FirecrawlError>
pub async fn scrape_url( &self, url: impl AsRef<str>, options: impl Into<Option<ScrapeOptions>>, ) -> Result<Document, FirecrawlError>
Scrapes a URL using the Firecrawl API.
Sourceimpl FirecrawlApp
impl FirecrawlApp
Sourcepub async fn search(
&self,
query: impl AsRef<str>,
options: impl Into<Option<SearchOptions>>,
) -> Result<Vec<SearchResult>, FirecrawlError>
pub async fn search( &self, query: impl AsRef<str>, options: impl Into<Option<SearchOptions>>, ) -> Result<Vec<SearchResult>, FirecrawlError>
Sourceimpl FirecrawlApp
impl FirecrawlApp
pub fn new(api_key: impl AsRef<str>) -> Result<FirecrawlApp, FirecrawlError>
pub fn new_with_client( api_key: impl AsRef<str>, client: Client, ) -> Result<FirecrawlApp, FirecrawlError>
pub fn new_selfhosted( api_url: impl AsRef<str>, api_key: Option<impl AsRef<str>>, ) -> Result<FirecrawlApp, FirecrawlError>
pub fn new_selfhosted_with_client( api_url: impl AsRef<str>, api_key: Option<impl AsRef<str>>, client: Client, ) -> Result<FirecrawlApp, FirecrawlError>